summaryrefslogtreecommitdiff
path: root/nuttx/configs/viewtool-stm32f107/src/stm32_buttons.c
diff options
context:
space:
mode:
Diffstat (limited to 'nuttx/configs/viewtool-stm32f107/src/stm32_buttons.c')
-rw-r--r--nuttx/configs/viewtool-stm32f107/src/stm32_buttons.c12
1 files changed, 6 insertions, 6 deletions
diff --git a/nuttx/configs/viewtool-stm32f107/src/stm32_buttons.c b/nuttx/configs/viewtool-stm32f107/src/stm32_buttons.c
index 0c2b623ea..4e9261f36 100644
--- a/nuttx/configs/viewtool-stm32f107/src/stm32_buttons.c
+++ b/nuttx/configs/viewtool-stm32f107/src/stm32_buttons.c
@@ -77,7 +77,7 @@ static const uint16_t g_buttons[NUM_BUTTONS] =
*
* Description:
* board_button_initialize() must be called to initialize button resources. After
* that, up_buttons() may be called to collect the current state of all
* buttons or up_irqbutton() may be called to register button interrupt
* handlers.
*
@@ -98,10 +98,10 @@ void board_button_initialize(void)
}
/****************************************************************************
- * Name: up_buttons
+ * Name: board_buttons
****************************************************************************/
-uint8_t up_buttons(void)
+uint8_t board_buttons(void)
{
uint8_t ret = 0;
int i;
@@ -132,12 +132,12 @@ uint8_t up_buttons(void)
*
* Description:
* board_button_initialize() must be called to initialize button resources. After
* that, up_buttons() may be called to collect the current state of all
* buttons or up_irqbutton() may be called to register button interrupt
* handlers.
*
* After board_button_initialize() has been called, up_buttons() may be called to
* collect the state of all buttons. up_buttons() returns an 8-bit bit set
* with each bit associated with a button. See the BUTTON_*_BIT and JOYSTICK_*_BIT
* definitions in board.h for the meaning of each bit.
*
@@ -77,7 +77,7 @@ static const uint16_t g_buttons[NUM_BUTTONS] =
* Description:
* board_button_initialize() must be called to initialize button resources. After
- * that, up_buttons() may be called to collect the current state of all
+ * that, board_buttons() may be called to collect the current state of all
* buttons or up_irqbutton() may be called to register button interrupt
* handlers.
@@ -132,12 +132,12 @@ uint8_t up_buttons(void)
* Description:
* board_button_initialize() must be called to initialize button resources. After
- * that, up_buttons() may be called to collect the current state of all
+ * that, board_buttons() may be called to collect the current state of all
* buttons or up_irqbutton() may be called to register button interrupt
* handlers.
@@ -132,12 +132,12 @@ uint8_t up_buttons(void)
* handlers.
*
- * After board_button_initialize() has been called, up_buttons() may be called to
- * collect the state of all buttons. up_buttons() returns an 8-bit bit set
+ * After board_button_initialize() has been called, board_buttons() may be called to
+ * collect the state of all buttons. board_buttons() returns an 8-bit bit set
* with each bit associated with a button. See the BUTTON_*_BIT and JOYSTICK_*_BIT
* definitions in board.h for the meaning of each bit.